Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
pydelica/__init__.py | 281 | 95 | 0 | 66%
pydelica/compiler.py | 158 | 51 | 0 | 68%
pydelica/exception.py | 66 | 16 | 0 | 76%
pydelica/logger.py | 11 | 0 | 0 | 100%
pydelica/model.py | 75 | 12 | 0 | 84%
pydelica/options/__init__.py | 5 | 0 | 0 | 100%
pydelica/options/library.py | 78 | 21 | 0 | 73%
pydelica/options/runtime.py | 217 | 8 | 0 | 96%
pydelica/options/simulation.py | 44 | 7 | 0 | 84%
pydelica/solutions.py | 20 | 1 | 0 | 95%
Total | 955 | 211 | 0 | 78%

No items found using the specified filter.